Authors
=======

Lead Developers
---------------
- `Yalin Li`_ (current maintainer)
- `Joy Zhang`_


Code Development
----------------
- `Yalin Li`_
- `Joy Zhang`_
- `Other developers <https://github.com/QSD-Group/QSDsan/graphs/contributors>`_ that have contributed to the repository.


Module Development
------------------
- `Yalin Li`_
- `Joy Zhang`_
- Stetson Rowles
- Smiti Mittal
- Anna Kogler
- Samuel Aguiar
- Tyler Stephen
- Shion Watabe


Tutorials and Videos
--------------------
- `Yalin Li`_
- `Joy Zhang`_
- Tori Morgan
- Hannah Lohman


Project Conception
------------------
- `Jeremy Guest`_


Funding Support
---------------
- `Jeremy Guest`_


Special Acknowledgement
-----------------------
- Yoel Cortés-Peña for helping many of the ``QSDsan`` members get started on Python and package development.


.. Links
.. _Yalin Li: mailto:zoe.yalin.li@gmail.com
.. _Joy Zhang: mailto:joycheung1994@gmail.com
.. _Jeremy Guest: mailto:jsguest@illinois.edu
